@@ -13,9 +13,6 @@
 #    copyright notice, this list of conditions and the following
 #    disclaimer in the documentation and/or other materials provided
 #    with the distribution.
-#  * Neither the name of Willow Garage, Inc. nor the names of its
-#    contributors may be used to endorse or promote products derived
-#    from this software without specific prior written permission.
 #
 # THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 # "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -38,6 +35,7 @@ __pychecker__ = '--unusednames=cls,options,subdirs'
 
 COMMON_SOURCE = 'common_source'
 
+
 class CommonSourcePlugin(UnilintPlugin):
     """Identifies files and folders with python code (heuristically)"""
 
@@ -62,8 +60,10 @@ class CommonSourcePlugin(UnilintPlugin):
                     result[path] = ['script']
 
         # TODO use os.path functions
-        if ('/doc/' in path or '/doc-pak/' in path or
-            path.endswith('/doc') or path.endswith('doc-pak')):
+        if '/doc/' in path or \
+                '/doc-pak/' in path or \
+                path.endswith('/doc') or \
+                path.endswith('doc-pak'):
             if path not in result:
                 result[path] = ['doc']
             else:
@@ -75,22 +75,25 @@ class CommonSourcePlugin(UnilintPlugin):
             else:
                 result[path].append('test')
 
-        if files is None:
-            files = path
-        for filename in files:
-            for prefix in ['.', '_', '#']:
+        if not files:
+            files = [path]
+
+        for filepath in files:
+            filename = os.path.basename(filepath)
+            def _categorize(path, filepath, category):
+                if filepath != path:
+                    filepath = os.path.join(path, filepath)
+                result[filepath] = [category]
+            for prefix in ['.', '#']:
                 if filename.startswith(prefix):
-                    fullname = os.path.join(path, filename)
-                    result[fullname] = ['hidden']
+                    _categorize(path, filepath, 'hidden')
                     break
             for suffix in ['~', '.orig', '.bak']:
                 if filename.endswith(suffix):
-                    fullname = os.path.join(path, filename)
-                    result[fullname] = ['backup']
+                    _categorize(path, filepath, 'backup')
                     break
             for infix in ['.BACKUP.', '.BASE.', '.LOCAL.', '.REMOTE.']:
                 if infix in filename:
-                    fullname = os.path.join(path, filename)
-                    result[fullname] = ['backup']
+                    _categorize(path, filepath, 'backup')
                     break
         return result
