@@ -13,9 +13,6 @@
 #    copyright notice, this list of conditions and the following
 #    disclaimer in the documentation and/or other materials provided
 #    with the distribution.
-#  * Neither the name of Willow Garage, Inc. nor the names of its
-#    contributors may be used to endorse or promote products derived
-#    from this software without specific prior written permission.
 #
 # THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 # "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -56,13 +53,15 @@ class CppSourcePlugin(UnilintPlugin):
 
     def categorize_type(self, options, path, subdirs, files):
         result = {}
-        if files is None:
+        if not files:
             files = [path]
 
-        for filename in files:
+        for filepath in files:
+            filename = os.path.basename(filepath)
             if CPP_FILE_PATTERN.match(filename) is not None:
-                filename = os.path.join(path, filename)
-                result[filename] = ['cpp-file']
+                if filepath != path:
+                    filepath = os.path.join(path, filepath)
+                result[filepath] = ['cpp-file']
 
         return result
 
