@@ -13,9 +13,6 @@
 #    copyright notice, this list of conditions and the following
 #    disclaimer in the documentation and/or other materials provided
 #    with the distribution.
-#  * Neither the name of Willow Garage, Inc. nor the names of its
-#    contributors may be used to endorse or promote products derived
-#    from this software without specific prior written permission.
 #
 # THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 # "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -57,9 +54,9 @@ class Pep8Plugin(AbstractPythonPlugin):
         raise UnilintPluginInitException("ERROR Cannot find pep8, install via apt or pip\n%s" % message)
 
     def check_resource(self, options, path, type_categories):
-        if (not 'python-src' in type_categories and
-            not 'script' in type_categories and
-            not 'python-module' in type_categories):
+        if not 'python-src' in type_categories and \
+                not 'script' in type_categories and \
+                not 'python-module' in type_categories:
             return None
 
         levels = []
@@ -99,7 +96,7 @@ class Pep8Plugin(AbstractPythonPlugin):
                 continue
             tokens = line.split(':', 3)
             (category, message) = tokens[3].strip().split(' ', 1)
-            severity=None
+            severity = None
             if category.startswith('E'):
                 severity = "warning"
             if category.startswith('W'):
