@@ -13,9 +13,6 @@
 #    copyright notice, this list of conditions and the following
 #    disclaimer in the documentation and/or other materials provided
 #    with the distribution.
-#  * Neither the name of Willow Garage, Inc. nor the names of its
-#    contributors may be used to endorse or promote products derived
-#    from this software without specific prior written permission.
 #
 # THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 # "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -30,7 +27,6 @@
 # ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
-import os
 from unilint.python_source_plugin import AbstractPythonPlugin
 from unilint.unilint_plugin import UnilintPluginInitException
 from unilint.issue import Issue
@@ -58,11 +54,11 @@ class PyflakesPlugin(AbstractPythonPlugin):
         return False
 
     def check_resource(self, options, path, type_categories):
-        if (not 'python-src' in type_categories and
-            not 'script' in type_categories):
+        if not 'python-src' in type_categories and \
+                not 'script' in type_categories:
             return None
 
-        cmd = "pyflakes %s"%path
+        cmd = "pyflakes %s" % path
         if options.verbose:
             print(cmd)
         _, output, _ = self.shell_cmd(cmd,
