@@ -13,9 +13,6 @@
 #    copyright notice, this list of conditions and the following
 #    disclaimer in the documentation and/or other materials provided
 #    with the distribution.
-#  * Neither the name of Willow Garage, Inc. nor the names of its
-#    contributors may be used to endorse or promote products derived
-#    from this software without specific prior written permission.
 #
 # THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 # "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -38,7 +35,7 @@ from unilint.issue import Issue
 
 import re
 
-NEWLINE_MATCHER=re.compile('^.+:[0-9]+: \[')
+NEWLINE_MATCHER = re.compile('^.+:[0-9]+: \[')
 
 
 class PylintPlugin(AbstractPythonPlugin):
@@ -61,8 +58,8 @@ class PylintPlugin(AbstractPythonPlugin):
         raise UnilintPluginInitException("ERROR Cannot find pylint, install via apt or pip\n%s" % message)
 
     def check_resource(self, options, path, type_categories):
-        if (not 'python-src' in type_categories and
-            not 'script' in type_categories):
+        if not 'python-src' in type_categories and \
+                not 'script' in type_categories:
             return None
 
         levels = []
@@ -118,7 +115,7 @@ class PylintPlugin(AbstractPythonPlugin):
             message_line = issue_lines[0]
             if len(issue_lines) > 1:
                 # source = issue_lines[1]
-                position = len(issue_lines[2]) -1
+                position = len(issue_lines[2]) - 1
             else:
                 # source = None
                 position = None
