@@ -13,9 +13,6 @@
 #    copyright notice, this list of conditions and the following
 #    disclaimer in the documentation and/or other materials provided
 #    with the distribution.
-#  * Neither the name of Willow Garage, Inc. nor the names of its
-#    contributors may be used to endorse or promote products derived
-#    from this software without specific prior written permission.
 #
 # THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 # "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -51,15 +48,18 @@ class PythonSourcePlugin(UnilintPlugin):
 
     def categorize_type(self, options, path, subdirs, files):
         result = {}
-        if files is None:
+        if not files:
             files = [path]
-        for filename in files:
+        for filepath in files:
+            filename = os.path.basename(filepath)
             if filename == 'setup.py':
-                filename = os.path.join(path, filename)
-                result[filename] = ['script']
+                if filepath != path:
+                    filepath = os.path.join(path, filepath)
+                result[filepath] = ['script']
             elif filename.endswith('.py'):
-                filename = os.path.join(path, filename)
-                result[filename] = ['python-src']
+                if filepath != path:
+                    filepath = os.path.join(path, filepath)
+                result[filepath] = ['python-src']
 
         return result
 
