@@ -61,7 +61,7 @@ def resolve_plugins(selected_plugins_string,
         selected_plugins_ids = selected_plugins_string.split(',')
 
         for plugin_id in selected_plugins_ids:
-            if plugin_id.strip()=='':
+            if plugin_id.strip() == '':
                 continue
             if not plugin_id in PLUGINS:
                 raise UnilintException('Unknown plugin: %s' % plugin_id)
@@ -72,8 +72,8 @@ def resolve_plugins(selected_plugins_string,
             deselected_plugins_ids = deselected_plugins_string.split(',')
 
         for plugin_id in PLUGINS:
-            if (plugin_id not in deselected_plugins_ids
-                and PLUGINS[plugin_id].is_enabled_by_default()):
+            if plugin_id not in deselected_plugins_ids and \
+                    PLUGINS[plugin_id].is_enabled_by_default():
                 result_plugin_ids.append(plugin_id)
 
     dependencies = []
@@ -119,12 +119,16 @@ def remove_duplicates(issues):
             for oldissue in sameline_issues:
                 # for now, will rely on manually crafted duplicate
                 # detection
-                for keyword in ['too long',
-                                'indentation contains',
-                                'variable ']:
-                    if keyword in oldissue.message and \
-                            keyword in issue.message:
-                        is_duplicate = True
+                for keyword_vector in [('too long'),
+                                       ('indentation contains'),
+                                       ('variable '),
+                                       ('not used', 'unused')]:
+                    if keyword_vector[0] in oldissue.message:
+                        for keyword_match in keyword_vector:
+                            if keyword_match in issue.message:
+                                is_duplicate = True
+                                break
+                    if is_duplicate:
                         break
             if is_duplicate:
                 continue
@@ -132,6 +136,7 @@ def remove_duplicates(issues):
         result.append(issue)
     return result
 
+
 def print_issues(args, issues, path):
     """
     print to stdout
@@ -176,6 +181,9 @@ def check_path(path_to_check,
     :param subdirs: subdirectories
     :param files: the files to check
     """
+    if not os.path.exists(path_to_check):
+        print('Ignoring argument that does not exist: %s' % path_to_check)
+        return
     issues = []
     categorized_resources = {}
     for plugin_id in args.selected_plugins:
@@ -240,7 +248,7 @@ def run_cmd(paths, args):
         return 0
 
     args.selected_plugins = resolve_plugins(args.selected_plugins,
-                                               args.deselected_plugins)
+                                            args.deselected_plugins)
 
     issues = []
     for path in paths:
@@ -385,4 +393,3 @@ def unilint_main(argv):
     args, paths = evaluate_options(args)
 
     return run_cmd(paths, args)
-
